@@ -77,6 +77,7 @@ class DebugJob(Job[R]):
         os.environ.update(self.environ)
 
         root_logger = logging.getLogger("")
+        self.paths.stdout.parent.mkdir(exist_ok=True, parents=True)
         stdout_handler = logging.FileHandler(self.paths.stdout)
         stdout_handler.setLevel(logging.DEBUG)
         stderr_handler = logging.FileHandler(self.paths.stderr)
@@ -138,6 +139,10 @@ class DebugJob(Job[R]):
     def get_info(self, mode: str = "force") -> Dict[str, str]:  # pylint: disable=unused-argument
         return {"STATE": self.state}
 
+    def __del__(self) -> None:
+        # Skip parent code
+        return
+
 
 class DebugExecutor(Executor):
 
